"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/** @typedef {'slow-2g' | '2g' | '3g' | '4g'} EffectiveConnectionType */
/** @typedef {{effectiveType: EffectiveConnectionType}} NetworkInformation */
/** @type {{ connection?: NetworkInformation, mozConnection?: NetworkInformation, webkitConnection?: NetworkInformation, deviceMemory?: number, hardwareConcurrency?:number, userAgent: string } | null} */
const nav = typeof navigator !== 'undefined' ? navigator : null;
/**
 * Get effective connection type.
 * https://developer.mozilla.org/en-US/docs/Web/API/NetworkInformation
 *
 * @return {EffectiveConnectionType | null}
 */
function getEffectiveConnectionType() {
    const conn = nav ? nav.connection || nav.mozConnection || nav.webkitConnection : null;
    return conn ? conn.effectiveType : null;
}
exports.getEffectiveConnectionType = getEffectiveConnectionType;
/**
 * Get device memory in GB rounded to 2.
 * https://developer.mozilla.org/en-US/docs/Web/API/Navigator/deviceMemory
 *
 * @return {number | null}
 */
function getDeviceMemory() {
    return nav ? nav.deviceMemory || null : null;
}
exports.getDeviceMemory = getDeviceMemory;
/**
 * Get CPU cores.
 *
 * @return {number | null}
 */
function getHardwareConcurrency() {
    return nav ? nav.hardwareConcurrency || null : null;
}
exports.getHardwareConcurrency = getHardwareConcurrency;
/**
 * Get current url.
 *
 * @return {string | null}
 */
function getUrl() {
    return typeof location !== 'undefined' ? location.href : null;
}
exports.getUrl = getUrl;
/**
 * Get user-agent header.
 *
 * @return {string | null}
 */
function getUserAgent() {
    return nav ? nav.userAgent : null;
}
exports.getUserAgent = getUserAgent;
