/**
 * Create performance observer.
 *
 * @param {EventType} eventType
 * @param {PerformanceEventCallback} cb
 * @return {PerformanceObserver | null}
 */
export function createPerformanceObserver(eventType: "navigation" | "mark" | "element" | "first-input" | "largest-contentful-paint" | "layout-shift" | "longtask" | "measure" | "paint" | "resource" | "eliment-timing" | "long-task", cb: (events: PerformanceEntry[]) => any): PerformanceObserver | null;
/**
 * Get buffered events by `type`.
 *
 * @param {EventType} eventType
 * @return {Promise<PerformanceEntry[]>}
 */
export function getEventsByType(eventType: "navigation" | "mark" | "element" | "first-input" | "largest-contentful-paint" | "layout-shift" | "longtask" | "measure" | "paint" | "resource" | "eliment-timing" | "long-task"): Promise<PerformanceEntry[]>;
export namespace performanceEvents {
    /**
     * Subscribe on the `metric`.
     *
     * @param {EventType} eventType
     * @param {PerformanceEventCallback} cb
     */
    export function on(eventType: "navigation" | "mark" | "element" | "first-input" | "largest-contentful-paint" | "layout-shift" | "longtask" | "measure" | "paint" | "resource" | "eliment-timing" | "long-task", cb: (events: PerformanceEntry[]) => any): {
        on(eventType: "navigation" | "mark" | "element" | "first-input" | "largest-contentful-paint" | "layout-shift" | "longtask" | "measure" | "paint" | "resource" | "eliment-timing" | "long-task", cb: (events: PerformanceEntry[]) => any): any;
        /**
         * Unsubscribe `metric` listener.
         *
         * @param {EventType} eventType
         * @param {PerformanceEventCallback} cb
         */
        off(eventType: "navigation" | "mark" | "element" | "first-input" | "largest-contentful-paint" | "layout-shift" | "longtask" | "measure" | "paint" | "resource" | "eliment-timing" | "long-task", cb: (events: PerformanceEntry[]) => any): void;
    };
    /**
     * Unsubscribe `metric` listener.
     *
     * @param {EventType} eventType
     * @param {PerformanceEventCallback} cb
     */
    export function off(eventType: "navigation" | "mark" | "element" | "first-input" | "largest-contentful-paint" | "layout-shift" | "longtask" | "measure" | "paint" | "resource" | "eliment-timing" | "long-task", cb: (events: PerformanceEntry[]) => any): void;
}
export type PerformanceEventCallback = (events: PerformanceEntry[]) => any;
export type StrictEventType = "navigation" | "mark" | "element" | "first-input" | "largest-contentful-paint" | "layout-shift" | "longtask" | "measure" | "paint" | "resource";
export type EventType = "navigation" | "mark" | "element" | "first-input" | "largest-contentful-paint" | "layout-shift" | "longtask" | "measure" | "paint" | "resource" | "eliment-timing" | "long-task";
